.. _${full-name}-welcome:

${full-name}
${=}

Write the documentation for **${full-name}**.

Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Authors <authors>
   Release Notes <changelog>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
